BrainBitResistData class

Constructors

BrainBitResistData({required double o1, required double o2, required double t3, required double t4})

Properties

hashCode → int
The hash code for this object.
no setterinherited
o1 → double
final
o2 → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
t3 → double
final
t4 → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited